@@ -24,7 +24,7 @@ dsaidemenu <- function() {
 #needed to prevent NOTE messages on CRAN checks
 #most of those are from the ggplot commands in the generate_ functions,
 #the last one is from the subset function in the fit functions
-utils::globalVariables(c("xvals", "yvals", "varnames","IDvar","style","Condition", "simfunction"))
+utils::globalVariables(c("xvals", "yvals", "varnames","IDvar","style","Condition", "simfunction","flu1918data","norodata"))
 
 
 .onAttach <- function(libname, pkgname){
