@@ -4,6 +4,18 @@
 ## ---- eval=FALSE, echo=TRUE----------------------------------------------
 #  dsaidemenu()
 
+## ----dsaidemenu,  fig.cap='Main menu of the DSAIDE package.', echo=FALSE----
+knitr::include_graphics("mainmenu.png")
+
+## ----appexample,  fig.cap='Screenshot of the input-output elements of one of the apps.', echo=FALSE----
+knitr::include_graphics("appexample.png")
+
+## ----modelexample,  fig.cap='Screenshot of the _Model_ section of one of the apps.', echo=FALSE----
+knitr::include_graphics("modelexample.png")
+
+## ----whattodoexample,  fig.cap='Screenshot of the _What to do_ section of one of the apps.', echo=FALSE----
+knitr::include_graphics("whattodoexample.png")
+
 ## ----eval=TRUE, echo=FALSE-----------------------------------------------
 library('DSAIDE') 
 
