@@ -3,7 +3,7 @@ context("test-generate_text.R")
 
 test_that("generate_text returns text string",
           {
-            simresult=DSAIDE::simulate_idcharacteristics()
+            simresult=DSAIDE::simulate_idcharacteristics_ode()
             result = vector("list", 1)
             result[[1]]$dat = simresult$ts
             #no maketext provided, should be character of length 1
